@@ -6,6 +6,10 @@
 #' Only \code{full} is currently supported.
 #' @param url Regulome url address. 
 #' Default: <http://www.regulomedb.org/results>
+#' @param timeout A \code{timeout} parameter for \code{curl}.
+#' Default: 10
+#' @param check_bad_snps Checks if all SNPs are annotated.
+#' Default: \code{TRUE}
 #' @param verbose Verbosing output. Default: FALSE.
 #' @return A list of two:
 #' (1) a data frame (table) and
@@ -22,6 +26,8 @@
 queryRegulome <- function(query=NULL, 
                           format = "full",
                           url="http://www.regulomedb.org/results",
+                          timeout=10,
+                          check_bad_snps=TRUE,
                           verbose=FALSE) {
   
     if(format != "full") {
@@ -34,12 +40,14 @@ queryRegulome <- function(query=NULL,
     tryCatch({
         # First find the bad snp ids #
         qr <- paste(query, collapse = ',') 
-        dataHaploReg <- queryHaploreg(qr)
-        bad.snp.id <- dataHaploReg[which(dataHaploReg$GENCODE_id == "" &
+        if(check_bad_snps) {
+            dataHaploReg <- queryHaploreg(qr,timeout=timeout)
+            bad.snp.id <- dataHaploReg[which(dataHaploReg$GENCODE_id == "" &
                                          dataHaploReg$chr == "" & 
                                          dataHaploReg$dbSNP_functional_annotation == ""), "rsID"]
         
-        query <- query[which(!(query %in% bad.snp.id))]
+            query <- query[which(!(query %in% bad.snp.id))]
+        }
         # End of filtering bad snps #
         
         # Searching #
@@ -49,7 +57,7 @@ queryRegulome <- function(query=NULL,
         body <- list(data = qr)
         # Form encoded
         # Multipart encoded
-        r <- POST(url, body = body, encode = encode)
+        r <- POST(url, body = body, encode = encode, timeout(timeout))
         bin <- content(r, "raw")
         dat <- readBin(bin, character())
   
@@ -61,7 +69,7 @@ queryRegulome <- function(query=NULL,
         body <- list(format=format, sid = sid)
         # Form encoded
         # Multipart encoded
-        r <- POST(url, body = body, encode = encode,  timeout(10))
+        r <- POST(url, body = body, encode = encode,  timeout(timeout))
         bin <- content(r, "raw")
         dat <- readBin(bin, character())
   
@@ -72,10 +80,18 @@ queryRegulome <- function(query=NULL,
                            function(n) { unlist(strsplit(sp[n], '\t')) } )
         res.table <- do.call(rbind.data.frame, res.rows)
         colnames(res.table) <- res.header
-        
     }, error=function(e) {
         print(e)
     })
     
-    return(list(res.table=res.table, bad.snp.id=bad.snp.id))
+    for(i in 1:dim(res.table)[2]) {
+        res.table[,i] <- as.character(res.table[,i])
+        col.num.conv <- suppressWarnings(as.numeric(res.table[,i]))
+        na.rate <- length(which(is.na(col.num.conv)))/length(col.num.conv)
+        if(na.rate <= 0.5) {
+            res.table[,i] <- col.num.conv
+        }
+    }
+    
+    return(list(res.table=as_tibble(res.table), bad.snp.id=bad.snp.id))
 }
\ No newline at end of file
